techs

package
v0.0.0-...-9610229 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 14, 2020 License: GPL-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

const (
	LevelNil = iota
	LevelWarn
	LevelErr
	LevelCrit
)

Variables

This section is empty.

Functions

This section is empty.

Types

type Finding

type Finding struct {
	Ev    events.Event
	Found bool
	Level int
}

type L1001

type L1001 struct {
	// contains filtered or unexported fields
}

func (L1001) Check

func (t L1001) Check() (Finding, error)

func (L1001) Clean

func (t L1001) Clean(e events.Event) error

func (L1001) Hunt

func (t L1001) Hunt() (Finding, error)

func (L1001) Mitigate

func (t L1001) Mitigate() error

func (L1001) Name

func (t L1001) Name() string

func (L1001) Scan

func (t L1001) Scan(e events.Event) Finding

type L1002

type L1002 struct {
	// contains filtered or unexported fields
}

func (L1002) Check

func (t L1002) Check() (Finding, error)

func (L1002) Clean

func (t L1002) Clean(e events.Event) error

func (L1002) Hunt

func (t L1002) Hunt() (Finding, error)

func (L1002) Mitigate

func (t L1002) Mitigate() error

func (L1002) Name

func (t L1002) Name() string

func (L1002) Scan

func (t L1002) Scan(e events.Event) Finding

type L1003

type L1003 struct {
	// contains filtered or unexported fields
}

func (L1003) Check

func (t L1003) Check() (Finding, error)

func (L1003) Clean

func (t L1003) Clean(e events.Event) error

func (L1003) Hunt

func (t L1003) Hunt() (Finding, error)

func (L1003) Mitigate

func (t L1003) Mitigate() error

func (L1003) Name

func (t L1003) Name() string

func (L1003) Scan

func (t L1003) Scan(e events.Event) Finding

type L1004

type L1004 struct {
	// contains filtered or unexported fields
}

func (L1004) Check

func (t L1004) Check() (Finding, error)

func (L1004) Clean

func (t L1004) Clean(e events.Event) error

func (L1004) Hunt

func (t L1004) Hunt() (Finding, error)

func (L1004) Mitigate

func (t L1004) Mitigate() error

func (L1004) Name

func (t L1004) Name() string

func (L1004) Scan

func (t L1004) Scan(e events.Event) Finding

type L1005

type L1005 struct {
	// contains filtered or unexported fields
}

func (L1005) Check

func (t L1005) Check() (Finding, error)

func (L1005) Clean

func (t L1005) Clean(e events.Event) error

func (L1005) Hunt

func (t L1005) Hunt() (Finding, error)

func (L1005) Mitigate

func (t L1005) Mitigate() error

func (L1005) Name

func (t L1005) Name() string

func (L1005) Scan

func (t L1005) Scan(e events.Event) Finding

type T1098

type T1098 struct {
	// contains filtered or unexported fields
}

func (T1098) Check

func (t T1098) Check() (Finding, error)

func (T1098) Clean

func (t T1098) Clean(e events.Event) error

func (T1098) Hunt

func (t T1098) Hunt() (Finding, error)

func (T1098) Mitigate

func (t T1098) Mitigate() error

func (T1098) Name

func (t T1098) Name() string

func (T1098) Scan

func (t T1098) Scan(e events.Event) Finding

type T1547

type T1547 struct {
	// contains filtered or unexported fields
}

func (T1547) Check

func (t T1547) Check() (Finding, error)

func (T1547) Clean

func (t T1547) Clean(e events.Event) error

func (T1547) Hunt

func (t T1547) Hunt() (Finding, error)

func (T1547) Mitigate

func (t T1547) Mitigate() error

func (T1547) Name

func (t T1547) Name() string

func (T1547) Scan

func (t T1547) Scan(e events.Event) Finding

type Tech

type Tech interface {
	Name() string

	// Scan handles input stream of events
	Scan(events.Event) Finding
	// Hunt takes no parameters and looks for evidence of exploitation
	Hunt() (Finding, error)
	// Clean responds to events detected by Scan or Hunt by removing artifacts
	Clean(events.Event) error
	// Check determines if vulnerability mitigation is required
	Check() (Finding, error)
	// Mitigation mitigates the vulnerability
	Mitigate() error
}

func All

func All() []Tech

Jump to