Documentation
¶
Index ¶
Constants ¶
const ( LevelNil = iota LevelWarn LevelErr LevelCrit )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Tech ¶
type Tech interface {
Name() string
// Scan handles input stream of events
Scan(events.Event) Finding
// Hunt takes no parameters and looks for evidence of exploitation
Hunt() (Finding, error)
// Clean responds to events detected by Scan or Hunt by removing artifacts
Clean(events.Event) error
// Check determines if vulnerability mitigation is required
Check() (Finding, error)
// Mitigation mitigates the vulnerability
Mitigate() error
}
Click to show internal directories.
Click to hide internal directories.